@@ -1,5 +1,5 @@
 Logit <-
-function(my_formula, data=d, rows=NULL, ref_group=NULL,
+function(my_formula, data=d, filter=NULL, ref_group=NULL,
          digits_d=4, text_width=120, 
 
          brief=getOption("brief"),
@@ -107,10 +107,11 @@ function(my_formula, data=d, rows=NULL, ref_group=NULL,
   n.vars <- length(nm)
   n.pred <- n.vars - 1
 
-  if (!missing(rows)) {  # subset rows
-    r <- eval(substitute(rows), envir=data, enclos=parent.frame())
+  if (!missing(filter)) {  # subset rows
+    r <- eval(substitute(filter), envir=data, enclos=parent.frame())
     r <- r & !is.na(r)  # set missing for a row to FALSE
-    data <- data[r,,drop=FALSE]
+    if (any(r))
+      data <- data[r,,drop=FALSE]
   }
   n.obs <- nrow(data)
   
